@@ -493,7 +493,7 @@ class Trivialscan:
                     continue
                 self._transport.store.evaluations.append(evaluation_result)
                 cli.outputln(
-                    evaluation_result.name,
+                    f"{evaluation_result.group_id}.{evaluation_result.rule_id} {evaluation_result.name}",
                     bold_result=True,
                     aside=f"SHA1:{cert.sha1_fingerprint} {self._transport.store.tls_state.hostname}:{self._transport.store.tls_state.port}",
                     con=self._console,
@@ -559,7 +559,7 @@ class Trivialscan:
                     continue
                 self._transport.store.evaluations.append(evaluation_result)
                 cli.outputln(
-                    evaluation_result.name,
+                    f"{evaluation_result.group_id}.{evaluation_result.rule_id} {evaluation_result.name}",
                     bold_result=True,
                     hostname=self._transport.store.tls_state.hostname,
                     port=self._transport.store.tls_state.port,
@@ -626,7 +626,7 @@ class Trivialscan:
                 continue
             self._transport.store.evaluations.append(evaluation_result)
             cli.outputln(
-                evaluation_result.name,
+                f"{evaluation_result.group_id}.{evaluation_result.rule_id} {evaluation_result.name}",
                 bold_result=True,
                 hostname=self._transport.store.tls_state.hostname,
                 port=self._transport.store.tls_state.port,
